@@ -8,7 +8,8 @@ use Carp;
 use Data::Dump qw( dump );
 use File::Temp;
 use MyApp::Form;
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 
 __PACKAGE__->config(
     primary_key => 'absolute',
